# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cudo_compute.api_client import ApiClient


class ObjectStorageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def activate(self, project_id, activate_body, **kwargs):  # noqa: E501
        """Allow the use of S3 compatible storage in a project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate(project_id, activate_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param ActivateBody activate_body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.activate_with_http_info(project_id, activate_body, **kwargs)  # noqa: E501
        else:
            (data) = self.activate_with_http_info(project_id, activate_body, **kwargs)  # noqa: E501
            return data

    def activate_with_http_info(self, project_id, activate_body, **kwargs):  # noqa: E501
        """Allow the use of S3 compatible storage in a project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_with_http_info(project_id, activate_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param ActivateBody activate_body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'activate_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `activate`")  # noqa: E501
        # verify the required parameter 'activate_body' is set
        if self.api_client.client_side_validation and ('activate_body' not in params or
                                                       params['activate_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `activate_body` when calling `activate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'activate_body' in params:
            body_params = params['activate_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/activate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_object_storage_user(self, project_id, create_object_storage_user_body, **kwargs):  # noqa: E501
        """Create user that stores keys for storage buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_object_storage_user(project_id, create_object_storage_user_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateObjectStorageUserBody create_object_storage_user_body: (required)
        :return: ObjectStorageUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_object_storage_user_with_http_info(project_id, create_object_storage_user_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_object_storage_user_with_http_info(project_id, create_object_storage_user_body, **kwargs)  # noqa: E501
            return data

    def create_object_storage_user_with_http_info(self, project_id, create_object_storage_user_body, **kwargs):  # noqa: E501
        """Create user that stores keys for storage buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_object_storage_user_with_http_info(project_id, create_object_storage_user_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateObjectStorageUserBody create_object_storage_user_body: (required)
        :return: ObjectStorageUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'create_object_storage_user_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_object_storage_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_object_storage_user`")  # noqa: E501
        # verify the required parameter 'create_object_storage_user_body' is set
        if self.api_client.client_side_validation and ('create_object_storage_user_body' not in params or
                                                       params['create_object_storage_user_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_object_storage_user_body` when calling `create_object_storage_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_object_storage_user_body' in params:
            body_params = params['create_object_storage_user_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ObjectStorageUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_object_storage_key(self, project_id, id, **kwargs):  # noqa: E501
        """Delete object storage user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_object_storage_key(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str access_key:
        :return: DeleteObjectStorageKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_object_storage_key_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_object_storage_key_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def delete_object_storage_key_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete object storage user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_object_storage_key_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str access_key:
        :return: DeleteObjectStorageKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'access_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_object_storage_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_object_storage_key`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_object_storage_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'access_key' in params:
            query_params.append(('accessKey', params['access_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users/{id}/keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteObjectStorageKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_object_storage_user(self, project_id, id, **kwargs):  # noqa: E501
        """Delete object storage user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_object_storage_user(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteObjectStorageUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_object_storage_user_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_object_storage_user_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def delete_object_storage_user_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete object storage user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_object_storage_user_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteObjectStorageUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_object_storage_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_object_storage_user`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_object_storage_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteObjectStorageUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_object_storage_key(self, project_id, id, generate_object_storage_key_body, **kwargs):  # noqa: E501
        """Generate access key for storage buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_object_storage_key(project_id, id, generate_object_storage_key_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param object generate_object_storage_key_body: (required)
        :return: ObjectStorageKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_object_storage_key_with_http_info(project_id, id, generate_object_storage_key_body, **kwargs)  # noqa: E501
        else:
            (data) = self.generate_object_storage_key_with_http_info(project_id, id, generate_object_storage_key_body, **kwargs)  # noqa: E501
            return data

    def generate_object_storage_key_with_http_info(self, project_id, id, generate_object_storage_key_body, **kwargs):  # noqa: E501
        """Generate access key for storage buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_object_storage_key_with_http_info(project_id, id, generate_object_storage_key_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param object generate_object_storage_key_body: (required)
        :return: ObjectStorageKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'generate_object_storage_key_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_object_storage_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `generate_object_storage_key`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `generate_object_storage_key`")  # noqa: E501
        # verify the required parameter 'generate_object_storage_key_body' is set
        if self.api_client.client_side_validation and ('generate_object_storage_key_body' not in params or
                                                       params['generate_object_storage_key_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `generate_object_storage_key_body` when calling `generate_object_storage_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'generate_object_storage_key_body' in params:
            body_params = params['generate_object_storage_key_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ObjectStorageKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_object_storage_bucket(self, project_id, id, **kwargs):  # noqa: E501
        """Get details for a bucket  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_bucket(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ObjectStorageBucket
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_object_storage_bucket_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_object_storage_bucket_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_object_storage_bucket_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get details for a bucket  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_bucket_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ObjectStorageBucket
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_object_storage_bucket" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_object_storage_bucket`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_object_storage_bucket`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/buckets/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ObjectStorageBucket',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_object_storage_session_key(self, project_id, **kwargs):  # noqa: E501
        """Generate temporary key for storage bucket access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_session_key(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str data_center_id:
        :return: GetObjectStorageSessionKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_object_storage_session_key_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_object_storage_session_key_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def get_object_storage_session_key_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """Generate temporary key for storage bucket access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_session_key_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str data_center_id:
        :return: GetObjectStorageSessionKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'data_center_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_object_storage_session_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_object_storage_session_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'data_center_id' in params:
            query_params.append(('dataCenterId', params['data_center_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/session-key', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetObjectStorageSessionKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_object_storage_buckets(self, project_id, **kwargs):  # noqa: E501
        """List buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_buckets(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageBucketsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_object_storage_buckets_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_object_storage_buckets_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_object_storage_buckets_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List buckets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_buckets_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageBucketsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_object_storage_buckets" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_object_storage_buckets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/buckets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListObjectStorageBucketsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_object_storage_keys(self, project_id, id, **kwargs):  # noqa: E501
        """List storage user keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_keys(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_object_storage_keys_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_object_storage_keys_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def list_object_storage_keys_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """List storage user keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_keys_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_object_storage_keys" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_object_storage_keys`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_object_storage_keys`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users/{id}/keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListObjectStorageKeysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_object_storage_users(self, project_id, **kwargs):  # noqa: E501
        """List storage users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_users(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageUsersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_object_storage_users_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_object_storage_users_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_object_storage_users_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List storage users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_users_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListObjectStorageUsersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_object_storage_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_object_storage_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/object-storage/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListObjectStorageUsersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class GetMachineTypeLiveUtilizationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_utilization': 'float',
        'gpu_free': 'int',
        'gpu_total': 'int',
        'gpu_used': 'int',
        'gpu_utilization': 'float',
        'memory_gib_free': 'int',
        'memory_gib_total': 'int',
        'memory_gib_used': 'int',
        'memory_utilization': 'float',
        'utilization': 'float',
        'vcpu_free': 'int',
        'vcpu_total': 'int',
        'vcpu_used': 'int'
    }

    attribute_map = {
        'cpu_utilization': 'cpuUtilization',
        'gpu_free': 'gpuFree',
        'gpu_total': 'gpuTotal',
        'gpu_used': 'gpuUsed',
        'gpu_utilization': 'gpuUtilization',
        'memory_gib_free': 'memoryGibFree',
        'memory_gib_total': 'memoryGibTotal',
        'memory_gib_used': 'memoryGibUsed',
        'memory_utilization': 'memoryUtilization',
        'utilization': 'utilization',
        'vcpu_free': 'vcpuFree',
        'vcpu_total': 'vcpuTotal',
        'vcpu_used': 'vcpuUsed'
    }

    def __init__(self, cpu_utilization=None, gpu_free=None, gpu_total=None, gpu_used=None, gpu_utilization=None, memory_gib_free=None, memory_gib_total=None, memory_gib_used=None, memory_utilization=None, utilization=None, vcpu_free=None, vcpu_total=None, vcpu_used=None, _configuration=None):  # noqa: E501
        """GetMachineTypeLiveUtilizationResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_utilization = None
        self._gpu_free = None
        self._gpu_total = None
        self._gpu_used = None
        self._gpu_utilization = None
        self._memory_gib_free = None
        self._memory_gib_total = None
        self._memory_gib_used = None
        self._memory_utilization = None
        self._utilization = None
        self._vcpu_free = None
        self._vcpu_total = None
        self._vcpu_used = None
        self.discriminator = None

        self.cpu_utilization = cpu_utilization
        self.gpu_free = gpu_free
        self.gpu_total = gpu_total
        self.gpu_used = gpu_used
        self.gpu_utilization = gpu_utilization
        self.memory_gib_free = memory_gib_free
        self.memory_gib_total = memory_gib_total
        self.memory_gib_used = memory_gib_used
        self.memory_utilization = memory_utilization
        self.utilization = utilization
        self.vcpu_free = vcpu_free
        self.vcpu_total = vcpu_total
        self.vcpu_used = vcpu_used

    @property
    def cpu_utilization(self):
        """Gets the cpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The cpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: float
        """
        return self._cpu_utilization

    @cpu_utilization.setter
    def cpu_utilization(self, cpu_utilization):
        """Sets the cpu_utilization of this GetMachineTypeLiveUtilizationResponse.


        :param cpu_utilization: The cpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and cpu_utilization is None:
            raise ValueError("Invalid value for `cpu_utilization`, must not be `None`")  # noqa: E501

        self._cpu_utilization = cpu_utilization

    @property
    def gpu_free(self):
        """Gets the gpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The gpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._gpu_free

    @gpu_free.setter
    def gpu_free(self, gpu_free):
        """Sets the gpu_free of this GetMachineTypeLiveUtilizationResponse.


        :param gpu_free: The gpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and gpu_free is None:
            raise ValueError("Invalid value for `gpu_free`, must not be `None`")  # noqa: E501

        self._gpu_free = gpu_free

    @property
    def gpu_total(self):
        """Gets the gpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The gpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._gpu_total

    @gpu_total.setter
    def gpu_total(self, gpu_total):
        """Sets the gpu_total of this GetMachineTypeLiveUtilizationResponse.


        :param gpu_total: The gpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and gpu_total is None:
            raise ValueError("Invalid value for `gpu_total`, must not be `None`")  # noqa: E501

        self._gpu_total = gpu_total

    @property
    def gpu_used(self):
        """Gets the gpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The gpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._gpu_used

    @gpu_used.setter
    def gpu_used(self, gpu_used):
        """Sets the gpu_used of this GetMachineTypeLiveUtilizationResponse.


        :param gpu_used: The gpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and gpu_used is None:
            raise ValueError("Invalid value for `gpu_used`, must not be `None`")  # noqa: E501

        self._gpu_used = gpu_used

    @property
    def gpu_utilization(self):
        """Gets the gpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The gpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: float
        """
        return self._gpu_utilization

    @gpu_utilization.setter
    def gpu_utilization(self, gpu_utilization):
        """Sets the gpu_utilization of this GetMachineTypeLiveUtilizationResponse.


        :param gpu_utilization: The gpu_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and gpu_utilization is None:
            raise ValueError("Invalid value for `gpu_utilization`, must not be `None`")  # noqa: E501

        self._gpu_utilization = gpu_utilization

    @property
    def memory_gib_free(self):
        """Gets the memory_gib_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The memory_gib_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib_free

    @memory_gib_free.setter
    def memory_gib_free(self, memory_gib_free):
        """Sets the memory_gib_free of this GetMachineTypeLiveUtilizationResponse.


        :param memory_gib_free: The memory_gib_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib_free is None:
            raise ValueError("Invalid value for `memory_gib_free`, must not be `None`")  # noqa: E501

        self._memory_gib_free = memory_gib_free

    @property
    def memory_gib_total(self):
        """Gets the memory_gib_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The memory_gib_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib_total

    @memory_gib_total.setter
    def memory_gib_total(self, memory_gib_total):
        """Sets the memory_gib_total of this GetMachineTypeLiveUtilizationResponse.


        :param memory_gib_total: The memory_gib_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib_total is None:
            raise ValueError("Invalid value for `memory_gib_total`, must not be `None`")  # noqa: E501

        self._memory_gib_total = memory_gib_total

    @property
    def memory_gib_used(self):
        """Gets the memory_gib_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The memory_gib_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib_used

    @memory_gib_used.setter
    def memory_gib_used(self, memory_gib_used):
        """Sets the memory_gib_used of this GetMachineTypeLiveUtilizationResponse.


        :param memory_gib_used: The memory_gib_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib_used is None:
            raise ValueError("Invalid value for `memory_gib_used`, must not be `None`")  # noqa: E501

        self._memory_gib_used = memory_gib_used

    @property
    def memory_utilization(self):
        """Gets the memory_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The memory_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: float
        """
        return self._memory_utilization

    @memory_utilization.setter
    def memory_utilization(self, memory_utilization):
        """Sets the memory_utilization of this GetMachineTypeLiveUtilizationResponse.


        :param memory_utilization: The memory_utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and memory_utilization is None:
            raise ValueError("Invalid value for `memory_utilization`, must not be `None`")  # noqa: E501

        self._memory_utilization = memory_utilization

    @property
    def utilization(self):
        """Gets the utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: float
        """
        return self._utilization

    @utilization.setter
    def utilization(self, utilization):
        """Sets the utilization of this GetMachineTypeLiveUtilizationResponse.


        :param utilization: The utilization of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and utilization is None:
            raise ValueError("Invalid value for `utilization`, must not be `None`")  # noqa: E501

        self._utilization = utilization

    @property
    def vcpu_free(self):
        """Gets the vcpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The vcpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_free

    @vcpu_free.setter
    def vcpu_free(self, vcpu_free):
        """Sets the vcpu_free of this GetMachineTypeLiveUtilizationResponse.


        :param vcpu_free: The vcpu_free of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_free is None:
            raise ValueError("Invalid value for `vcpu_free`, must not be `None`")  # noqa: E501

        self._vcpu_free = vcpu_free

    @property
    def vcpu_total(self):
        """Gets the vcpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The vcpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_total

    @vcpu_total.setter
    def vcpu_total(self, vcpu_total):
        """Sets the vcpu_total of this GetMachineTypeLiveUtilizationResponse.


        :param vcpu_total: The vcpu_total of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_total is None:
            raise ValueError("Invalid value for `vcpu_total`, must not be `None`")  # noqa: E501

        self._vcpu_total = vcpu_total

    @property
    def vcpu_used(self):
        """Gets the vcpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501


        :return: The vcpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_used

    @vcpu_used.setter
    def vcpu_used(self, vcpu_used):
        """Sets the vcpu_used of this GetMachineTypeLiveUtilizationResponse.


        :param vcpu_used: The vcpu_used of this GetMachineTypeLiveUtilizationResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_used is None:
            raise ValueError("Invalid value for `vcpu_used`, must not be `None`")  # noqa: E501

        self._vcpu_used = vcpu_used

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetMachineTypeLiveUtilizationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetMachineTypeLiveUtilizationResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetMachineTypeLiveUtilizationResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class HostConfigCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count_vm_available': 'int',
        'cpu_model': 'str',
        'data_center_id': 'str',
        'gpu_model': 'str',
        'gpu_price_hr': 'Decimal',
        'id': 'str',
        'ipv4_price_hr': 'Decimal',
        'machine_type': 'str',
        'memory_gib_price_hr': 'Decimal',
        'renewable_energy': 'bool',
        'storage_gib_price_hr': 'Decimal',
        'total_gpu_price_hr': 'Decimal',
        'total_memory_price_hr': 'Decimal',
        'total_price_hr': 'Decimal',
        'total_storage_price_hr': 'Decimal',
        'total_vcpu_price_hr': 'Decimal',
        'vcpu_price_hr': 'Decimal'
    }

    attribute_map = {
        'count_vm_available': 'countVmAvailable',
        'cpu_model': 'cpuModel',
        'data_center_id': 'dataCenterId',
        'gpu_model': 'gpuModel',
        'gpu_price_hr': 'gpuPriceHr',
        'id': 'id',
        'ipv4_price_hr': 'ipv4PriceHr',
        'machine_type': 'machineType',
        'memory_gib_price_hr': 'memoryGibPriceHr',
        'renewable_energy': 'renewableEnergy',
        'storage_gib_price_hr': 'storageGibPriceHr',
        'total_gpu_price_hr': 'totalGpuPriceHr',
        'total_memory_price_hr': 'totalMemoryPriceHr',
        'total_price_hr': 'totalPriceHr',
        'total_storage_price_hr': 'totalStoragePriceHr',
        'total_vcpu_price_hr': 'totalVcpuPriceHr',
        'vcpu_price_hr': 'vcpuPriceHr'
    }

    def __init__(self, count_vm_available=None, cpu_model=None, data_center_id=None, gpu_model=None, gpu_price_hr=None, id=None, ipv4_price_hr=None, machine_type=None, memory_gib_price_hr=None, renewable_energy=None, storage_gib_price_hr=None, total_gpu_price_hr=None, total_memory_price_hr=None, total_price_hr=None, total_storage_price_hr=None, total_vcpu_price_hr=None, vcpu_price_hr=None, _configuration=None):  # noqa: E501
        """HostConfigCategory - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._count_vm_available = None
        self._cpu_model = None
        self._data_center_id = None
        self._gpu_model = None
        self._gpu_price_hr = None
        self._id = None
        self._ipv4_price_hr = None
        self._machine_type = None
        self._memory_gib_price_hr = None
        self._renewable_energy = None
        self._storage_gib_price_hr = None
        self._total_gpu_price_hr = None
        self._total_memory_price_hr = None
        self._total_price_hr = None
        self._total_storage_price_hr = None
        self._total_vcpu_price_hr = None
        self._vcpu_price_hr = None
        self.discriminator = None

        self.count_vm_available = count_vm_available
        self.cpu_model = cpu_model
        self.data_center_id = data_center_id
        self.gpu_model = gpu_model
        self.gpu_price_hr = gpu_price_hr
        self.id = id
        self.ipv4_price_hr = ipv4_price_hr
        self.machine_type = machine_type
        self.memory_gib_price_hr = memory_gib_price_hr
        self.renewable_energy = renewable_energy
        self.storage_gib_price_hr = storage_gib_price_hr
        self.total_gpu_price_hr = total_gpu_price_hr
        self.total_memory_price_hr = total_memory_price_hr
        self.total_price_hr = total_price_hr
        self.total_storage_price_hr = total_storage_price_hr
        self.total_vcpu_price_hr = total_vcpu_price_hr
        self.vcpu_price_hr = vcpu_price_hr

    @property
    def count_vm_available(self):
        """Gets the count_vm_available of this HostConfigCategory.  # noqa: E501


        :return: The count_vm_available of this HostConfigCategory.  # noqa: E501
        :rtype: int
        """
        return self._count_vm_available

    @count_vm_available.setter
    def count_vm_available(self, count_vm_available):
        """Sets the count_vm_available of this HostConfigCategory.


        :param count_vm_available: The count_vm_available of this HostConfigCategory.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_vm_available is None:
            raise ValueError("Invalid value for `count_vm_available`, must not be `None`")  # noqa: E501

        self._count_vm_available = count_vm_available

    @property
    def cpu_model(self):
        """Gets the cpu_model of this HostConfigCategory.  # noqa: E501


        :return: The cpu_model of this HostConfigCategory.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this HostConfigCategory.


        :param cpu_model: The cpu_model of this HostConfigCategory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and cpu_model is None:
            raise ValueError("Invalid value for `cpu_model`, must not be `None`")  # noqa: E501

        self._cpu_model = cpu_model

    @property
    def data_center_id(self):
        """Gets the data_center_id of this HostConfigCategory.  # noqa: E501


        :return: The data_center_id of this HostConfigCategory.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this HostConfigCategory.


        :param data_center_id: The data_center_id of this HostConfigCategory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and data_center_id is None:
            raise ValueError("Invalid value for `data_center_id`, must not be `None`")  # noqa: E501

        self._data_center_id = data_center_id

    @property
    def gpu_model(self):
        """Gets the gpu_model of this HostConfigCategory.  # noqa: E501


        :return: The gpu_model of this HostConfigCategory.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model

    @gpu_model.setter
    def gpu_model(self, gpu_model):
        """Sets the gpu_model of this HostConfigCategory.


        :param gpu_model: The gpu_model of this HostConfigCategory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gpu_model is None:
            raise ValueError("Invalid value for `gpu_model`, must not be `None`")  # noqa: E501

        self._gpu_model = gpu_model

    @property
    def gpu_price_hr(self):
        """Gets the gpu_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The gpu_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._gpu_price_hr

    @gpu_price_hr.setter
    def gpu_price_hr(self, gpu_price_hr):
        """Sets the gpu_price_hr of this HostConfigCategory.


        :param gpu_price_hr: The gpu_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and gpu_price_hr is None:
            raise ValueError("Invalid value for `gpu_price_hr`, must not be `None`")  # noqa: E501

        self._gpu_price_hr = gpu_price_hr

    @property
    def id(self):
        """Gets the id of this HostConfigCategory.  # noqa: E501


        :return: The id of this HostConfigCategory.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HostConfigCategory.


        :param id: The id of this HostConfigCategory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ipv4_price_hr(self):
        """Gets the ipv4_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The ipv4_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._ipv4_price_hr

    @ipv4_price_hr.setter
    def ipv4_price_hr(self, ipv4_price_hr):
        """Sets the ipv4_price_hr of this HostConfigCategory.


        :param ipv4_price_hr: The ipv4_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and ipv4_price_hr is None:
            raise ValueError("Invalid value for `ipv4_price_hr`, must not be `None`")  # noqa: E501

        self._ipv4_price_hr = ipv4_price_hr

    @property
    def machine_type(self):
        """Gets the machine_type of this HostConfigCategory.  # noqa: E501


        :return: The machine_type of this HostConfigCategory.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this HostConfigCategory.


        :param machine_type: The machine_type of this HostConfigCategory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and machine_type is None:
            raise ValueError("Invalid value for `machine_type`, must not be `None`")  # noqa: E501

        self._machine_type = machine_type

    @property
    def memory_gib_price_hr(self):
        """Gets the memory_gib_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The memory_gib_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._memory_gib_price_hr

    @memory_gib_price_hr.setter
    def memory_gib_price_hr(self, memory_gib_price_hr):
        """Sets the memory_gib_price_hr of this HostConfigCategory.


        :param memory_gib_price_hr: The memory_gib_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and memory_gib_price_hr is None:
            raise ValueError("Invalid value for `memory_gib_price_hr`, must not be `None`")  # noqa: E501

        self._memory_gib_price_hr = memory_gib_price_hr

    @property
    def renewable_energy(self):
        """Gets the renewable_energy of this HostConfigCategory.  # noqa: E501


        :return: The renewable_energy of this HostConfigCategory.  # noqa: E501
        :rtype: bool
        """
        return self._renewable_energy

    @renewable_energy.setter
    def renewable_energy(self, renewable_energy):
        """Sets the renewable_energy of this HostConfigCategory.


        :param renewable_energy: The renewable_energy of this HostConfigCategory.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and renewable_energy is None:
            raise ValueError("Invalid value for `renewable_energy`, must not be `None`")  # noqa: E501

        self._renewable_energy = renewable_energy

    @property
    def storage_gib_price_hr(self):
        """Gets the storage_gib_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The storage_gib_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._storage_gib_price_hr

    @storage_gib_price_hr.setter
    def storage_gib_price_hr(self, storage_gib_price_hr):
        """Sets the storage_gib_price_hr of this HostConfigCategory.


        :param storage_gib_price_hr: The storage_gib_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and storage_gib_price_hr is None:
            raise ValueError("Invalid value for `storage_gib_price_hr`, must not be `None`")  # noqa: E501

        self._storage_gib_price_hr = storage_gib_price_hr

    @property
    def total_gpu_price_hr(self):
        """Gets the total_gpu_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The total_gpu_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._total_gpu_price_hr

    @total_gpu_price_hr.setter
    def total_gpu_price_hr(self, total_gpu_price_hr):
        """Sets the total_gpu_price_hr of this HostConfigCategory.


        :param total_gpu_price_hr: The total_gpu_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and total_gpu_price_hr is None:
            raise ValueError("Invalid value for `total_gpu_price_hr`, must not be `None`")  # noqa: E501

        self._total_gpu_price_hr = total_gpu_price_hr

    @property
    def total_memory_price_hr(self):
        """Gets the total_memory_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The total_memory_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._total_memory_price_hr

    @total_memory_price_hr.setter
    def total_memory_price_hr(self, total_memory_price_hr):
        """Sets the total_memory_price_hr of this HostConfigCategory.


        :param total_memory_price_hr: The total_memory_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and total_memory_price_hr is None:
            raise ValueError("Invalid value for `total_memory_price_hr`, must not be `None`")  # noqa: E501

        self._total_memory_price_hr = total_memory_price_hr

    @property
    def total_price_hr(self):
        """Gets the total_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The total_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._total_price_hr

    @total_price_hr.setter
    def total_price_hr(self, total_price_hr):
        """Sets the total_price_hr of this HostConfigCategory.


        :param total_price_hr: The total_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and total_price_hr is None:
            raise ValueError("Invalid value for `total_price_hr`, must not be `None`")  # noqa: E501

        self._total_price_hr = total_price_hr

    @property
    def total_storage_price_hr(self):
        """Gets the total_storage_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The total_storage_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._total_storage_price_hr

    @total_storage_price_hr.setter
    def total_storage_price_hr(self, total_storage_price_hr):
        """Sets the total_storage_price_hr of this HostConfigCategory.


        :param total_storage_price_hr: The total_storage_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and total_storage_price_hr is None:
            raise ValueError("Invalid value for `total_storage_price_hr`, must not be `None`")  # noqa: E501

        self._total_storage_price_hr = total_storage_price_hr

    @property
    def total_vcpu_price_hr(self):
        """Gets the total_vcpu_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The total_vcpu_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._total_vcpu_price_hr

    @total_vcpu_price_hr.setter
    def total_vcpu_price_hr(self, total_vcpu_price_hr):
        """Sets the total_vcpu_price_hr of this HostConfigCategory.


        :param total_vcpu_price_hr: The total_vcpu_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and total_vcpu_price_hr is None:
            raise ValueError("Invalid value for `total_vcpu_price_hr`, must not be `None`")  # noqa: E501

        self._total_vcpu_price_hr = total_vcpu_price_hr

    @property
    def vcpu_price_hr(self):
        """Gets the vcpu_price_hr of this HostConfigCategory.  # noqa: E501


        :return: The vcpu_price_hr of this HostConfigCategory.  # noqa: E501
        :rtype: Decimal
        """
        return self._vcpu_price_hr

    @vcpu_price_hr.setter
    def vcpu_price_hr(self, vcpu_price_hr):
        """Sets the vcpu_price_hr of this HostConfigCategory.


        :param vcpu_price_hr: The vcpu_price_hr of this HostConfigCategory.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and vcpu_price_hr is None:
            raise ValueError("Invalid value for `vcpu_price_hr`, must not be `None`")  # noqa: E501

        self._vcpu_price_hr = vcpu_price_hr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HostConfigCategory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HostConfigCategory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HostConfigCategory):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cudo_compute.api_client import ApiClient


class APIKeysApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_api_key(self, name, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        Deletes an API key, revoking all access for requests that use the key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_api_key_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_api_key_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_api_key_with_http_info(self, name, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        Deletes an API key, revoking all access for requests that use the key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_api_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `delete_api_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Authorization']

        return self.api_client.call_api(
            '/v1/api-keys/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_api_key(self, generate_api_key_body, **kwargs):  # noqa: E501
        """Generate  # noqa: E501

        Creates a new API key for the requesting user. The API key is returned in the response, and this is the only time it can be viewed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_api_key(generate_api_key_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerateApiKeyRequest generate_api_key_body: (required)
        :return: ApiKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_api_key_with_http_info(generate_api_key_body, **kwargs)  # noqa: E501
        else:
            (data) = self.generate_api_key_with_http_info(generate_api_key_body, **kwargs)  # noqa: E501
            return data

    def generate_api_key_with_http_info(self, generate_api_key_body, **kwargs):  # noqa: E501
        """Generate  # noqa: E501

        Creates a new API key for the requesting user. The API key is returned in the response, and this is the only time it can be viewed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_api_key_with_http_info(generate_api_key_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerateApiKeyRequest generate_api_key_body: (required)
        :return: ApiKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['generate_api_key_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_api_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'generate_api_key_body' is set
        if self.api_client.client_side_validation and ('generate_api_key_body' not in params or
                                                       params['generate_api_key_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `generate_api_key_body` when calling `generate_api_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'generate_api_key_body' in params:
            body_params = params['generate_api_key_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Authorization']

        return self.api_client.call_api(
            '/v1/api-keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_api_keys(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        List the details of all API keys created by the requesting user. This does not include the API key itself which is only visible once when the API key is created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_api_keys(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_number:
        :param int page_size:
        :return: ListApiKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_api_keys_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_api_keys_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_api_keys_with_http_info(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        List the details of all API keys created by the requesting user. This does not include the API key itself which is only visible once when the API key is created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_api_keys_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_number:
        :param int page_size:
        :return: ListApiKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_api_keys" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Authorization']

        return self.api_client.call_api(
            '/v1/api-keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListApiKeysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class SshKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'create_time': 'datetime',
        'fingerprint': 'str',
        'id': 'str',
        'public_key': 'str',
        'type': 'str'
    }

    attribute_map = {
        'comment': 'comment',
        'create_time': 'createTime',
        'fingerprint': 'fingerprint',
        'id': 'id',
        'public_key': 'publicKey',
        'type': 'type'
    }

    def __init__(self, comment=None, create_time=None, fingerprint=None, id=None, public_key=None, type=None, _configuration=None):  # noqa: E501
        """SshKey - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._comment = None
        self._create_time = None
        self._fingerprint = None
        self._id = None
        self._public_key = None
        self._type = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if create_time is not None:
            self.create_time = create_time
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if id is not None:
            self.id = id
        self.public_key = public_key
        if type is not None:
            self.type = type

    @property
    def comment(self):
        """Gets the comment of this SshKey.  # noqa: E501


        :return: The comment of this SshKey.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SshKey.


        :param comment: The comment of this SshKey.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def create_time(self):
        """Gets the create_time of this SshKey.  # noqa: E501


        :return: The create_time of this SshKey.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this SshKey.


        :param create_time: The create_time of this SshKey.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def fingerprint(self):
        """Gets the fingerprint of this SshKey.  # noqa: E501


        :return: The fingerprint of this SshKey.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this SshKey.


        :param fingerprint: The fingerprint of this SshKey.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def id(self):
        """Gets the id of this SshKey.  # noqa: E501


        :return: The id of this SshKey.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SshKey.


        :param id: The id of this SshKey.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def public_key(self):
        """Gets the public_key of this SshKey.  # noqa: E501


        :return: The public_key of this SshKey.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this SshKey.


        :param public_key: The public_key of this SshKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and public_key is None:
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def type(self):
        """Gets the type of this SshKey.  # noqa: E501


        :return: The type of this SshKey.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SshKey.


        :param type: The type of this SshKey.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SshKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SshKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SshKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class ListVMMachineTypesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_model': 'str',
        'data_center_id': 'str',
        'gpu': 'int',
        'gpu_model': 'str',
        'memory_gib': 'int',
        'order_by': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'public_ipv4': 'bool',
        'region_id': 'str',
        'storage_gib': 'int',
        'vcpu': 'int'
    }

    attribute_map = {
        'cpu_model': 'cpuModel',
        'data_center_id': 'dataCenterId',
        'gpu': 'gpu',
        'gpu_model': 'gpuModel',
        'memory_gib': 'memoryGib',
        'order_by': 'orderBy',
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'public_ipv4': 'publicIpv4',
        'region_id': 'regionId',
        'storage_gib': 'storageGib',
        'vcpu': 'vcpu'
    }

    def __init__(self, cpu_model=None, data_center_id=None, gpu=None, gpu_model=None, memory_gib=None, order_by=None, page_number=None, page_size=None, public_ipv4=None, region_id=None, storage_gib=None, vcpu=None, _configuration=None):  # noqa: E501
        """ListVMMachineTypesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_model = None
        self._data_center_id = None
        self._gpu = None
        self._gpu_model = None
        self._memory_gib = None
        self._order_by = None
        self._page_number = None
        self._page_size = None
        self._public_ipv4 = None
        self._region_id = None
        self._storage_gib = None
        self._vcpu = None
        self.discriminator = None

        if cpu_model is not None:
            self.cpu_model = cpu_model
        if data_center_id is not None:
            self.data_center_id = data_center_id
        if gpu is not None:
            self.gpu = gpu
        if gpu_model is not None:
            self.gpu_model = gpu_model
        self.memory_gib = memory_gib
        if order_by is not None:
            self.order_by = order_by
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if public_ipv4 is not None:
            self.public_ipv4 = public_ipv4
        if region_id is not None:
            self.region_id = region_id
        if storage_gib is not None:
            self.storage_gib = storage_gib
        self.vcpu = vcpu

    @property
    def cpu_model(self):
        """Gets the cpu_model of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The cpu_model of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this ListVMMachineTypesRequest.


        :param cpu_model: The cpu_model of this ListVMMachineTypesRequest.  # noqa: E501
        :type: str
        """

        self._cpu_model = cpu_model

    @property
    def data_center_id(self):
        """Gets the data_center_id of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The data_center_id of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this ListVMMachineTypesRequest.


        :param data_center_id: The data_center_id of this ListVMMachineTypesRequest.  # noqa: E501
        :type: str
        """

        self._data_center_id = data_center_id

    @property
    def gpu(self):
        """Gets the gpu of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The gpu of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu):
        """Sets the gpu of this ListVMMachineTypesRequest.


        :param gpu: The gpu of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """

        self._gpu = gpu

    @property
    def gpu_model(self):
        """Gets the gpu_model of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The gpu_model of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model

    @gpu_model.setter
    def gpu_model(self, gpu_model):
        """Sets the gpu_model of this ListVMMachineTypesRequest.


        :param gpu_model: The gpu_model of this ListVMMachineTypesRequest.  # noqa: E501
        :type: str
        """

        self._gpu_model = gpu_model

    @property
    def memory_gib(self):
        """Gets the memory_gib of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The memory_gib of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib

    @memory_gib.setter
    def memory_gib(self, memory_gib):
        """Sets the memory_gib of this ListVMMachineTypesRequest.


        :param memory_gib: The memory_gib of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib is None:
            raise ValueError("Invalid value for `memory_gib`, must not be `None`")  # noqa: E501

        self._memory_gib = memory_gib

    @property
    def order_by(self):
        """Gets the order_by of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The order_by of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this ListVMMachineTypesRequest.


        :param order_by: The order_by of this ListVMMachineTypesRequest.  # noqa: E501
        :type: str
        """

        self._order_by = order_by

    @property
    def page_number(self):
        """Gets the page_number of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The page_number of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this ListVMMachineTypesRequest.


        :param page_number: The page_number of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The page_size of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ListVMMachineTypesRequest.


        :param page_size: The page_size of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def public_ipv4(self):
        """Gets the public_ipv4 of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The public_ipv4 of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._public_ipv4

    @public_ipv4.setter
    def public_ipv4(self, public_ipv4):
        """Sets the public_ipv4 of this ListVMMachineTypesRequest.


        :param public_ipv4: The public_ipv4 of this ListVMMachineTypesRequest.  # noqa: E501
        :type: bool
        """

        self._public_ipv4 = public_ipv4

    @property
    def region_id(self):
        """Gets the region_id of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The region_id of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this ListVMMachineTypesRequest.


        :param region_id: The region_id of this ListVMMachineTypesRequest.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def storage_gib(self):
        """Gets the storage_gib of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The storage_gib of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_gib

    @storage_gib.setter
    def storage_gib(self, storage_gib):
        """Sets the storage_gib of this ListVMMachineTypesRequest.


        :param storage_gib: The storage_gib of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """

        self._storage_gib = storage_gib

    @property
    def vcpu(self):
        """Gets the vcpu of this ListVMMachineTypesRequest.  # noqa: E501


        :return: The vcpu of this ListVMMachineTypesRequest.  # noqa: E501
        :rtype: int
        """
        return self._vcpu

    @vcpu.setter
    def vcpu(self, vcpu):
        """Sets the vcpu of this ListVMMachineTypesRequest.


        :param vcpu: The vcpu of this ListVMMachineTypesRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu is None:
            raise ValueError("Invalid value for `vcpu`, must not be `None`")  # noqa: E501

        self._vcpu = vcpu

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListVMMachineTypesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListVMMachineTypesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListVMMachineTypesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class GetObjectStorageSessionKeyResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_key': 'str',
        'endpoint': 'str',
        'secret_key': 'str',
        'session_name': 'str',
        'session_token': 'str'
    }

    attribute_map = {
        'access_key': 'accessKey',
        'endpoint': 'endpoint',
        'secret_key': 'secretKey',
        'session_name': 'sessionName',
        'session_token': 'sessionToken'
    }

    def __init__(self, access_key=None, endpoint=None, secret_key=None, session_name=None, session_token=None, _configuration=None):  # noqa: E501
        """GetObjectStorageSessionKeyResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._access_key = None
        self._endpoint = None
        self._secret_key = None
        self._session_name = None
        self._session_token = None
        self.discriminator = None

        if access_key is not None:
            self.access_key = access_key
        if endpoint is not None:
            self.endpoint = endpoint
        if secret_key is not None:
            self.secret_key = secret_key
        if session_name is not None:
            self.session_name = session_name
        if session_token is not None:
            self.session_token = session_token

    @property
    def access_key(self):
        """Gets the access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this GetObjectStorageSessionKeyResponse.


        :param access_key: The access_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def endpoint(self):
        """Gets the endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this GetObjectStorageSessionKeyResponse.


        :param endpoint: The endpoint of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def secret_key(self):
        """Gets the secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """Sets the secret_key of this GetObjectStorageSessionKeyResponse.


        :param secret_key: The secret_key of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._secret_key = secret_key

    @property
    def session_name(self):
        """Gets the session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_name

    @session_name.setter
    def session_name(self, session_name):
        """Sets the session_name of this GetObjectStorageSessionKeyResponse.


        :param session_name: The session_name of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._session_name = session_name

    @property
    def session_token(self):
        """Gets the session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501


        :return: The session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this GetObjectStorageSessionKeyResponse.


        :param session_token: The session_token of this GetObjectStorageSessionKeyResponse.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetObjectStorageSessionKeyResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetObjectStorageSessionKeyResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetObjectStorageSessionKeyResponse):
            return True

        return self.to_dict() != other.to_dict()



from cudo_compute import cudo_api
from cudo_compute.rest import ApiException
import json

try:
    api = cudo_api.virtual_machines()
    vm = api.get_vm(cudo_api.project_id(), 'my-vm-id')
    print(vm.to_dict())
except ApiException as e:
    print(e)



import json

def find_instances(obj, key, value, path=[]):
    instances = []
    if isinstance(obj, dict):
        for k, v in obj.items():
            new_path = path + [k]
            if k == key and v == value:
                instances.append(new_path)
            instances += find_instances(v, key, value, path=new_path)
    elif isinstance(obj, list):
        for i, v in enumerate(obj):
            new_path = path + [i]
            instances += find_instances(v, key, value, path=new_path)
    return instances


file_path = 'swagger/public.swagger.json'
with open(file_path, 'r') as file:
    json_data = json.load(file)

instances = find_instances(json_data, "name", "body")

# Print the paths of instances
for i in instances:
    json_data[i[0]][i[1]][i[2]][i[3]][i[4]]["name"] = json_data[i[0]][i[1]][i[2]]["operationId"] + "Body"

# remove id required
json_data['definitions']['Disk']['required'] = ['sizeGib']

with open('fix.swagger.json', 'w') as file:
    json.dump(json_data, file, indent=2)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class ListObjectStorageBucketsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'buckets': 'list[ObjectStorageBucket]',
        'page_number': 'int',
        'page_size': 'int',
        'total_count': 'int'
    }

    attribute_map = {
        'buckets': 'buckets',
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'total_count': 'totalCount'
    }

    def __init__(self, buckets=None, page_number=None, page_size=None, total_count=None, _configuration=None):  # noqa: E501
        """ListObjectStorageBucketsResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._buckets = None
        self._page_number = None
        self._page_size = None
        self._total_count = None
        self.discriminator = None

        self.buckets = buckets
        self.page_number = page_number
        self.page_size = page_size
        self.total_count = total_count

    @property
    def buckets(self):
        """Gets the buckets of this ListObjectStorageBucketsResponse.  # noqa: E501


        :return: The buckets of this ListObjectStorageBucketsResponse.  # noqa: E501
        :rtype: list[ObjectStorageBucket]
        """
        return self._buckets

    @buckets.setter
    def buckets(self, buckets):
        """Sets the buckets of this ListObjectStorageBucketsResponse.


        :param buckets: The buckets of this ListObjectStorageBucketsResponse.  # noqa: E501
        :type: list[ObjectStorageBucket]
        """
        if self._configuration.client_side_validation and buckets is None:
            raise ValueError("Invalid value for `buckets`, must not be `None`")  # noqa: E501

        self._buckets = buckets

    @property
    def page_number(self):
        """Gets the page_number of this ListObjectStorageBucketsResponse.  # noqa: E501


        :return: The page_number of this ListObjectStorageBucketsResponse.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this ListObjectStorageBucketsResponse.


        :param page_number: The page_number of this ListObjectStorageBucketsResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and page_number is None:
            raise ValueError("Invalid value for `page_number`, must not be `None`")  # noqa: E501

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this ListObjectStorageBucketsResponse.  # noqa: E501


        :return: The page_size of this ListObjectStorageBucketsResponse.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ListObjectStorageBucketsResponse.


        :param page_size: The page_size of this ListObjectStorageBucketsResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def total_count(self):
        """Gets the total_count of this ListObjectStorageBucketsResponse.  # noqa: E501


        :return: The total_count of this ListObjectStorageBucketsResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListObjectStorageBucketsResponse.


        :param total_count: The total_count of this ListObjectStorageBucketsResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and total_count is None:
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListObjectStorageBucketsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListObjectStorageBucketsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListObjectStorageBucketsResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class GetMachineTypeResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count_clusters': 'int',
        'count_hosts': 'int',
        'count_hosts_active': 'int',
        'count_hosts_inactive': 'int',
        'cpu_models': 'list[str]',
        'data_center_id': 'str',
        'gpu_models': 'list[str]',
        'machine_type': 'str',
        'max_gpu_price_hr': 'Decimal',
        'max_memory_gib_price_hr': 'Decimal',
        'max_vcpu_per_gpu': 'float',
        'max_vcpu_per_memory_gib': 'float',
        'max_vcpu_price_hr': 'Decimal',
        'min_gpu_price_hr': 'Decimal',
        'min_memory_gib_price_hr': 'Decimal',
        'min_vcpu_per_gpu': 'float',
        'min_vcpu_per_memory_gib': 'float',
        'min_vcpu_price_hr': 'Decimal'
    }

    attribute_map = {
        'count_clusters': 'countClusters',
        'count_hosts': 'countHosts',
        'count_hosts_active': 'countHostsActive',
        'count_hosts_inactive': 'countHostsInactive',
        'cpu_models': 'cpuModels',
        'data_center_id': 'dataCenterId',
        'gpu_models': 'gpuModels',
        'machine_type': 'machineType',
        'max_gpu_price_hr': 'maxGpuPriceHr',
        'max_memory_gib_price_hr': 'maxMemoryGibPriceHr',
        'max_vcpu_per_gpu': 'maxVcpuPerGpu',
        'max_vcpu_per_memory_gib': 'maxVcpuPerMemoryGib',
        'max_vcpu_price_hr': 'maxVcpuPriceHr',
        'min_gpu_price_hr': 'minGpuPriceHr',
        'min_memory_gib_price_hr': 'minMemoryGibPriceHr',
        'min_vcpu_per_gpu': 'minVcpuPerGpu',
        'min_vcpu_per_memory_gib': 'minVcpuPerMemoryGib',
        'min_vcpu_price_hr': 'minVcpuPriceHr'
    }

    def __init__(self, count_clusters=None, count_hosts=None, count_hosts_active=None, count_hosts_inactive=None, cpu_models=None, data_center_id=None, gpu_models=None, machine_type=None, max_gpu_price_hr=None, max_memory_gib_price_hr=None, max_vcpu_per_gpu=None, max_vcpu_per_memory_gib=None, max_vcpu_price_hr=None, min_gpu_price_hr=None, min_memory_gib_price_hr=None, min_vcpu_per_gpu=None, min_vcpu_per_memory_gib=None, min_vcpu_price_hr=None, _configuration=None):  # noqa: E501
        """GetMachineTypeResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._count_clusters = None
        self._count_hosts = None
        self._count_hosts_active = None
        self._count_hosts_inactive = None
        self._cpu_models = None
        self._data_center_id = None
        self._gpu_models = None
        self._machine_type = None
        self._max_gpu_price_hr = None
        self._max_memory_gib_price_hr = None
        self._max_vcpu_per_gpu = None
        self._max_vcpu_per_memory_gib = None
        self._max_vcpu_price_hr = None
        self._min_gpu_price_hr = None
        self._min_memory_gib_price_hr = None
        self._min_vcpu_per_gpu = None
        self._min_vcpu_per_memory_gib = None
        self._min_vcpu_price_hr = None
        self.discriminator = None

        self.count_clusters = count_clusters
        self.count_hosts = count_hosts
        self.count_hosts_active = count_hosts_active
        self.count_hosts_inactive = count_hosts_inactive
        self.cpu_models = cpu_models
        self.data_center_id = data_center_id
        self.gpu_models = gpu_models
        self.machine_type = machine_type
        self.max_gpu_price_hr = max_gpu_price_hr
        self.max_memory_gib_price_hr = max_memory_gib_price_hr
        self.max_vcpu_per_gpu = max_vcpu_per_gpu
        self.max_vcpu_per_memory_gib = max_vcpu_per_memory_gib
        self.max_vcpu_price_hr = max_vcpu_price_hr
        self.min_gpu_price_hr = min_gpu_price_hr
        self.min_memory_gib_price_hr = min_memory_gib_price_hr
        self.min_vcpu_per_gpu = min_vcpu_per_gpu
        self.min_vcpu_per_memory_gib = min_vcpu_per_memory_gib
        self.min_vcpu_price_hr = min_vcpu_price_hr

    @property
    def count_clusters(self):
        """Gets the count_clusters of this GetMachineTypeResponse.  # noqa: E501


        :return: The count_clusters of this GetMachineTypeResponse.  # noqa: E501
        :rtype: int
        """
        return self._count_clusters

    @count_clusters.setter
    def count_clusters(self, count_clusters):
        """Sets the count_clusters of this GetMachineTypeResponse.


        :param count_clusters: The count_clusters of this GetMachineTypeResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_clusters is None:
            raise ValueError("Invalid value for `count_clusters`, must not be `None`")  # noqa: E501

        self._count_clusters = count_clusters

    @property
    def count_hosts(self):
        """Gets the count_hosts of this GetMachineTypeResponse.  # noqa: E501


        :return: The count_hosts of this GetMachineTypeResponse.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts

    @count_hosts.setter
    def count_hosts(self, count_hosts):
        """Sets the count_hosts of this GetMachineTypeResponse.


        :param count_hosts: The count_hosts of this GetMachineTypeResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts is None:
            raise ValueError("Invalid value for `count_hosts`, must not be `None`")  # noqa: E501

        self._count_hosts = count_hosts

    @property
    def count_hosts_active(self):
        """Gets the count_hosts_active of this GetMachineTypeResponse.  # noqa: E501


        :return: The count_hosts_active of this GetMachineTypeResponse.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts_active

    @count_hosts_active.setter
    def count_hosts_active(self, count_hosts_active):
        """Sets the count_hosts_active of this GetMachineTypeResponse.


        :param count_hosts_active: The count_hosts_active of this GetMachineTypeResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts_active is None:
            raise ValueError("Invalid value for `count_hosts_active`, must not be `None`")  # noqa: E501

        self._count_hosts_active = count_hosts_active

    @property
    def count_hosts_inactive(self):
        """Gets the count_hosts_inactive of this GetMachineTypeResponse.  # noqa: E501


        :return: The count_hosts_inactive of this GetMachineTypeResponse.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts_inactive

    @count_hosts_inactive.setter
    def count_hosts_inactive(self, count_hosts_inactive):
        """Sets the count_hosts_inactive of this GetMachineTypeResponse.


        :param count_hosts_inactive: The count_hosts_inactive of this GetMachineTypeResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts_inactive is None:
            raise ValueError("Invalid value for `count_hosts_inactive`, must not be `None`")  # noqa: E501

        self._count_hosts_inactive = count_hosts_inactive

    @property
    def cpu_models(self):
        """Gets the cpu_models of this GetMachineTypeResponse.  # noqa: E501


        :return: The cpu_models of this GetMachineTypeResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._cpu_models

    @cpu_models.setter
    def cpu_models(self, cpu_models):
        """Sets the cpu_models of this GetMachineTypeResponse.


        :param cpu_models: The cpu_models of this GetMachineTypeResponse.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and cpu_models is None:
            raise ValueError("Invalid value for `cpu_models`, must not be `None`")  # noqa: E501

        self._cpu_models = cpu_models

    @property
    def data_center_id(self):
        """Gets the data_center_id of this GetMachineTypeResponse.  # noqa: E501


        :return: The data_center_id of this GetMachineTypeResponse.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this GetMachineTypeResponse.


        :param data_center_id: The data_center_id of this GetMachineTypeResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and data_center_id is None:
            raise ValueError("Invalid value for `data_center_id`, must not be `None`")  # noqa: E501

        self._data_center_id = data_center_id

    @property
    def gpu_models(self):
        """Gets the gpu_models of this GetMachineTypeResponse.  # noqa: E501


        :return: The gpu_models of this GetMachineTypeResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._gpu_models

    @gpu_models.setter
    def gpu_models(self, gpu_models):
        """Sets the gpu_models of this GetMachineTypeResponse.


        :param gpu_models: The gpu_models of this GetMachineTypeResponse.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and gpu_models is None:
            raise ValueError("Invalid value for `gpu_models`, must not be `None`")  # noqa: E501

        self._gpu_models = gpu_models

    @property
    def machine_type(self):
        """Gets the machine_type of this GetMachineTypeResponse.  # noqa: E501


        :return: The machine_type of this GetMachineTypeResponse.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this GetMachineTypeResponse.


        :param machine_type: The machine_type of this GetMachineTypeResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and machine_type is None:
            raise ValueError("Invalid value for `machine_type`, must not be `None`")  # noqa: E501

        self._machine_type = machine_type

    @property
    def max_gpu_price_hr(self):
        """Gets the max_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The max_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._max_gpu_price_hr

    @max_gpu_price_hr.setter
    def max_gpu_price_hr(self, max_gpu_price_hr):
        """Sets the max_gpu_price_hr of this GetMachineTypeResponse.


        :param max_gpu_price_hr: The max_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and max_gpu_price_hr is None:
            raise ValueError("Invalid value for `max_gpu_price_hr`, must not be `None`")  # noqa: E501

        self._max_gpu_price_hr = max_gpu_price_hr

    @property
    def max_memory_gib_price_hr(self):
        """Gets the max_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The max_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._max_memory_gib_price_hr

    @max_memory_gib_price_hr.setter
    def max_memory_gib_price_hr(self, max_memory_gib_price_hr):
        """Sets the max_memory_gib_price_hr of this GetMachineTypeResponse.


        :param max_memory_gib_price_hr: The max_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and max_memory_gib_price_hr is None:
            raise ValueError("Invalid value for `max_memory_gib_price_hr`, must not be `None`")  # noqa: E501

        self._max_memory_gib_price_hr = max_memory_gib_price_hr

    @property
    def max_vcpu_per_gpu(self):
        """Gets the max_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501


        :return: The max_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_vcpu_per_gpu

    @max_vcpu_per_gpu.setter
    def max_vcpu_per_gpu(self, max_vcpu_per_gpu):
        """Sets the max_vcpu_per_gpu of this GetMachineTypeResponse.


        :param max_vcpu_per_gpu: The max_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and max_vcpu_per_gpu is None:
            raise ValueError("Invalid value for `max_vcpu_per_gpu`, must not be `None`")  # noqa: E501

        self._max_vcpu_per_gpu = max_vcpu_per_gpu

    @property
    def max_vcpu_per_memory_gib(self):
        """Gets the max_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501


        :return: The max_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_vcpu_per_memory_gib

    @max_vcpu_per_memory_gib.setter
    def max_vcpu_per_memory_gib(self, max_vcpu_per_memory_gib):
        """Sets the max_vcpu_per_memory_gib of this GetMachineTypeResponse.


        :param max_vcpu_per_memory_gib: The max_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and max_vcpu_per_memory_gib is None:
            raise ValueError("Invalid value for `max_vcpu_per_memory_gib`, must not be `None`")  # noqa: E501

        self._max_vcpu_per_memory_gib = max_vcpu_per_memory_gib

    @property
    def max_vcpu_price_hr(self):
        """Gets the max_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The max_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._max_vcpu_price_hr

    @max_vcpu_price_hr.setter
    def max_vcpu_price_hr(self, max_vcpu_price_hr):
        """Sets the max_vcpu_price_hr of this GetMachineTypeResponse.


        :param max_vcpu_price_hr: The max_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and max_vcpu_price_hr is None:
            raise ValueError("Invalid value for `max_vcpu_price_hr`, must not be `None`")  # noqa: E501

        self._max_vcpu_price_hr = max_vcpu_price_hr

    @property
    def min_gpu_price_hr(self):
        """Gets the min_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The min_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._min_gpu_price_hr

    @min_gpu_price_hr.setter
    def min_gpu_price_hr(self, min_gpu_price_hr):
        """Sets the min_gpu_price_hr of this GetMachineTypeResponse.


        :param min_gpu_price_hr: The min_gpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and min_gpu_price_hr is None:
            raise ValueError("Invalid value for `min_gpu_price_hr`, must not be `None`")  # noqa: E501

        self._min_gpu_price_hr = min_gpu_price_hr

    @property
    def min_memory_gib_price_hr(self):
        """Gets the min_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The min_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._min_memory_gib_price_hr

    @min_memory_gib_price_hr.setter
    def min_memory_gib_price_hr(self, min_memory_gib_price_hr):
        """Sets the min_memory_gib_price_hr of this GetMachineTypeResponse.


        :param min_memory_gib_price_hr: The min_memory_gib_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and min_memory_gib_price_hr is None:
            raise ValueError("Invalid value for `min_memory_gib_price_hr`, must not be `None`")  # noqa: E501

        self._min_memory_gib_price_hr = min_memory_gib_price_hr

    @property
    def min_vcpu_per_gpu(self):
        """Gets the min_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501


        :return: The min_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501
        :rtype: float
        """
        return self._min_vcpu_per_gpu

    @min_vcpu_per_gpu.setter
    def min_vcpu_per_gpu(self, min_vcpu_per_gpu):
        """Sets the min_vcpu_per_gpu of this GetMachineTypeResponse.


        :param min_vcpu_per_gpu: The min_vcpu_per_gpu of this GetMachineTypeResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and min_vcpu_per_gpu is None:
            raise ValueError("Invalid value for `min_vcpu_per_gpu`, must not be `None`")  # noqa: E501

        self._min_vcpu_per_gpu = min_vcpu_per_gpu

    @property
    def min_vcpu_per_memory_gib(self):
        """Gets the min_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501


        :return: The min_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501
        :rtype: float
        """
        return self._min_vcpu_per_memory_gib

    @min_vcpu_per_memory_gib.setter
    def min_vcpu_per_memory_gib(self, min_vcpu_per_memory_gib):
        """Sets the min_vcpu_per_memory_gib of this GetMachineTypeResponse.


        :param min_vcpu_per_memory_gib: The min_vcpu_per_memory_gib of this GetMachineTypeResponse.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and min_vcpu_per_memory_gib is None:
            raise ValueError("Invalid value for `min_vcpu_per_memory_gib`, must not be `None`")  # noqa: E501

        self._min_vcpu_per_memory_gib = min_vcpu_per_memory_gib

    @property
    def min_vcpu_price_hr(self):
        """Gets the min_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501


        :return: The min_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :rtype: Decimal
        """
        return self._min_vcpu_price_hr

    @min_vcpu_price_hr.setter
    def min_vcpu_price_hr(self, min_vcpu_price_hr):
        """Sets the min_vcpu_price_hr of this GetMachineTypeResponse.


        :param min_vcpu_price_hr: The min_vcpu_price_hr of this GetMachineTypeResponse.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and min_vcpu_price_hr is None:
            raise ValueError("Invalid value for `min_vcpu_price_hr`, must not be `None`")  # noqa: E501

        self._min_vcpu_price_hr = min_vcpu_price_hr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetMachineTypeResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetMachineTypeResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetMachineTypeResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.permissions_api import PermissionsApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestPermissionsApi(unittest.TestCase):
    """PermissionsApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.permissions_api.PermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_billing_account_user_permission(self):
        """Test case for add_billing_account_user_permission

        Add billing account user  # noqa: E501
        """
        pass

    def test_add_data_center_user_permission(self):
        """Test case for add_data_center_user_permission

        Add data center user  # noqa: E501
        """
        pass

    def test_add_project_user_permission(self):
        """Test case for add_project_user_permission

        Add project user  # noqa: E501
        """
        pass

    def test_list_user_permissions(self):
        """Test case for list_user_permissions

        List  # noqa: E501
        """
        pass

    def test_remove_billing_account_user_permission(self):
        """Test case for remove_billing_account_user_permission

        Remove billing account user  # noqa: E501
        """
        pass

    def test_remove_data_center_user_permission(self):
        """Test case for remove_data_center_user_permission

        Remove data center user  # noqa: E501
        """
        pass

    def test_remove_project_user_permission(self):
        """Test case for remove_project_user_permission

        Remove project user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.object_storage_api import ObjectStorageApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestObjectStorageApi(unittest.TestCase):
    """ObjectStorageApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.object_storage_api.ObjectStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate(self):
        """Test case for activate

        Allow the use of S3 compatible storage in a project  # noqa: E501
        """
        pass

    def test_create_object_storage_user(self):
        """Test case for create_object_storage_user

        Create user that stores keys for storage buckets  # noqa: E501
        """
        pass

    def test_delete_object_storage_key(self):
        """Test case for delete_object_storage_key

        Delete object storage user  # noqa: E501
        """
        pass

    def test_delete_object_storage_user(self):
        """Test case for delete_object_storage_user

        Delete object storage user  # noqa: E501
        """
        pass

    def test_generate_object_storage_key(self):
        """Test case for generate_object_storage_key

        Generate access key for storage buckets  # noqa: E501
        """
        pass

    def test_get_object_storage_bucket(self):
        """Test case for get_object_storage_bucket

        Get details for a bucket  # noqa: E501
        """
        pass

    def test_get_object_storage_session_key(self):
        """Test case for get_object_storage_session_key

        Generate temporary key for storage bucket access  # noqa: E501
        """
        pass

    def test_list_object_storage_buckets(self):
        """Test case for list_object_storage_buckets

        List buckets  # noqa: E501
        """
        pass

    def test_list_object_storage_keys(self):
        """Test case for list_object_storage_keys

        List storage user keys  # noqa: E501
        """
        pass

    def test_list_object_storage_users(self):
        """Test case for list_object_storage_users

        List storage users  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.networks_api import NetworksApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestNetworksApi(unittest.TestCase):
    """NetworksApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.networks_api.NetworksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_network(self):
        """Test case for create_network

        Create network  # noqa: E501
        """
        pass

    def test_create_security_group(self):
        """Test case for create_security_group

        Create security group  # noqa: E501
        """
        pass

    def test_delete_network(self):
        """Test case for delete_network

        Delete network  # noqa: E501
        """
        pass

    def test_delete_security_group(self):
        """Test case for delete_security_group

        Delete security group  # noqa: E501
        """
        pass

    def test_get_network(self):
        """Test case for get_network

        Get network  # noqa: E501
        """
        pass

    def test_get_security_group(self):
        """Test case for get_security_group

        Get a security group  # noqa: E501
        """
        pass

    def test_list_networks(self):
        """Test case for list_networks

        List networks  # noqa: E501
        """
        pass

    def test_list_security_groups(self):
        """Test case for list_security_groups

        List security groups  # noqa: E501
        """
        pass

    def test_start_network(self):
        """Test case for start_network

        Start network  # noqa: E501
        """
        pass

    def test_stop_network(self):
        """Test case for stop_network

        Stop network  # noqa: E501
        """
        pass

    def test_update_security_group(self):
        """Test case for update_security_group

        Update security group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
